package com.eactive.eai.rms.onl.statistics.statisticinfo.osidinstistatistic;

import java.util.HashMap;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import com.eactive.eai.rms.common.base.BaseService;



/**
 * <pre>
 * 1. 기능 : 
 * 2. 처리 개요 : 
 *     - 
 * 3. 주의사항 : 
 * </pre>
 * @author  : yk
 * @version : $Revision: 1.1 $
 */
@Service("osidInstiStatisticService")
public class OsidInstiStatisticService extends BaseService  {
	@Autowired
	@Qualifier("osidInstiStatisticDAO")
    private OsidInstiStatisticDAO dao;
	
	public Integer selectCompanyListCount(HashMap paramMap) throws Exception {
		return dao.selectCompanyListCount(paramMap);
	}	
	
	public Integer selectApcodeListCount(HashMap paramMap) throws Exception {
		return dao.selectApcodeListCount(paramMap);
	}	
	
	public List selectCompanyList(HashMap paramMap) throws Exception {
		return dao.selectCompanyList(paramMap);
	}	
	
	public List selectApcodeList(HashMap paramMap) throws Exception {
		return dao.selectApcodeList(paramMap);
	}	
	
	public List selectNotInCompanyList(HashMap paramMap) throws Exception {
		return dao.selectNotInCompanyList(paramMap);
	}	
	
	public List selectNotInApcodeList(HashMap paramMap) throws Exception {
		return dao.selectNotInApcodeList(paramMap);
	}
	
	public Integer selectApcodeDuplchk(HashMap paramMap) throws Exception {
		return dao.selectApcodeDuplchk(paramMap);
	}
	
	public void insertCompanyList(HashMap paramMap) throws Exception {
		dao.insertCompanyList( paramMap);
	  }
	
	public void insertApCodeList(HashMap paramMap) throws Exception {
		dao.insertApCodeList( paramMap);
	  }
	
	public void deleteCompanyList(HashMap<String, Object> paramMap) throws Exception {
		 dao.deleteCompanyList(paramMap);
	}
	
	public void deleteApCodeList(HashMap<String, Object> paramMap) throws Exception {
		dao.deleteApCodeList(paramMap);
	}
	
	public List selectCronCompanyList(HashMap paramMap) throws Exception {
		return dao.selectCronCompanyList(paramMap);
	}	
	
	public List selectCronApCodeList(HashMap paramMap) throws Exception {
		return dao.selectCronApCodeList(paramMap);
	}	
	
	public void insertBlackCompanyList(HashMap paramMap) throws Exception {
		dao.insertBlackCompanyList( paramMap);
	 }
	
	public void insertBlackApCodeList(HashMap paramMap) throws Exception {
		dao.insertBlackApCodeList( paramMap);
	 }
	
	
	
	
}
